==> bigloo_2.4b.orig.tar.gz: bigloo2.4b/recette/number.scm <==
;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/number.scm                   */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sat Nov 28 10:52:56 1992                          */
;*    Last change :  Tue Jun 26 06:03:06 2001 (serrano)                */
;*                                                                     */
;*    On test les operateurs generiques sur les nombres                */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module number
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-number)))

;*---------------------------------------------------------------------*/
;*    test-number ...                                                  */
;*---------------------------------------------------------------------*/
(define (test-number)
   (test-module "number" "number.scm")
   (test "=" (= 1 1) #t)
   (test "=" (= 1 1 1) #t)
   (test "=" (= 1 2 1) #f)
   (test "=" (= 1.0 1.0 1.0) #t)
   (test "=" (= 1.0 2.0 1.0) #f)
   (test "<" (< 1 2) #t)
   (test "<" (< 1 1) #f) 
   (test "<" (< 2 1) #f)
   (test "<" (< 1 2 3) #t)
   (test "<" (< 1 2 1 3) #f)
   (test ">" (> 1 2) #f)
   (test ">" (> 1 1) #f)
   (test ">" (> 2 1) #t)
   (test ">" (> 3 2 1) #t)
   (test ">" (> 3 1 2 1) #f)
   (test ">=" (>= 1 2) #f)
   (test ">=" (>= 1 1) #t)
   (test ">=" (>= 2 1) #t)
   (test ">=" (>= 3 2 1) #t)
   (test ">=" (>= 3 1 2 1) #f)
   (test "<=" (<= 1 2) #t)
   (test "<=" (<= 1 1) #t)
   (test "<=" (<= 2 1) #f)
   (test "<=" (<= 1 2 3) #t)
   (test "<=" (<= 1 2 1 3) #f)
   (test "+" (+ 1 2 3 4) 10)
   (test "-" (- 1 2 3 4) -8)
   (test "-" (let ((x 4.0)) (- x)) -4.0)
   (test "*" (* 1 2 3 4) 24)
   (test "/" (/ 12 3 2 1) 2)
   (test "/" (/ (/ 4)) 4.0)
   (test "/fx" (/fx 5 4) 1)
   (test "/fx" (integer? (/fx 5 4)) #t)
   (test "zero?" (zero? 3) #f)
   (test "zero?" (zero? 0) #t)
   (test "zero?" (zero? 3.0) #f)
   (test "zero?" (zero? 0.0) #t)
   (test "positive?" (positive? 5.0) #t)
   (test "positive?" (positive? -5.0) #f)
   (test "positive?" (positive? 5) #t)
   (test "positive?" (positive? -5) #f)
   (test "negative?" (negative? 5.0) #f)
   (test "negative?" (negative? -5.0) #t)
   (test "negative?" (negative? 5) #f)
   (test "negative?" (negative? -5) #t)
   (test "odd?" (odd? 4) #f)
   (test "odd?" (odd? 3) #t)
   (test "even?" (even? 4) #t)
   (test "even?" (even? 3) #f)
   (test "max" (max 3 4) 4)
   (test "max" (max 3.9 4) 4)
   (test "min" (min 3 4) 3) 
   (test "min" (min 3.9 4) 3.9)
   (test "modulo" (modulo 13 4) 1)
   (test "remainder" (remainder 13 4) 1)
   (test "modulo" (modulo -13 4) 3)
   (test "remainder" (remainder -13 4) -1)
   (test "modulo" (modulo 13 -4) -3)
   (test "remainder" (remainder 13 -4) 1)
   (test "modulo" (modulo -13 -4) -1)
   (test "remainder" (remainder -13 -4) -1)
   (test "gcd" (gcd 32 -36) 4)
   (test "gcd" (gcd) 0)
   (test "lcm" (lcm 32 -36) 288)
   (test "lcm" (lcm) 1)
   (test "flonum->fixnum" (flonum->fixnum (cosfl 0.0)) 1)
   (test "atan" (tan (atan 1)) (fixnum->flonum 1))
   (test "flofix.<" (< 3.0 3) #f)
   (test "flofix.<" (< 3.1 3) #f)
   (test "flofix.<" (< 3.1 4) #t)
   (test "flofix.>" (> 3 3.0) #f)
   (test "flofix.>" (> 3 3.1) #f)
   (test "flofix.>" (> 4 3.1) #t)
   (test "flofix.<=" (<= 3 3.0) #t)
   (test "flofix.<=" (<= 3 3.1) #t)
   (test "flofix.<=" (<= 3 2.0) #f)
   (test "flofix.>=" (>= 3.0 3) #t)
   (test "flofix.>=" (>= 3.1 3) #t)
   (test "flofix.>=" (>= 3.1 4) #f)
   (let ((x 3.0) (y 3))
      (test "flofix.<" (< x y) #f))
   (let ((x 3.1) (y 3))
      (test "flofix.<" (< x y) #f))
   (let ((x 3.1) (y 4))
      (test "flofix.<" (< x y) #t))
   (let ((x 3) (y 3.0))
      (test "flofix.>" (> x y) #f))
   (let ((x 3) (y 3.1))
      (test "flofix.>" (> x y) #f))
   (let ((x 4) (y 3.1))
      (test "flofix.>" (> x y) #t))
   (let ((x 3) (y 3.0))
      (test "flofix.<=" (<= x y) #t))
   (let ((x 3) (y 3.1))
      (test "flofix.<=" (<= x y) #t))
   (let ((x 3) (y 2.0))
      (test "flofix.<=" (<= x y) #f))
   (let ((x 3.0) (y 3))
      (test "flofix.>=" (>= x y) #t))
   (let ((x 3.1) (y 3))
      (test "flofix.>=" (>= 3.1 3) #t))
   (let ((x 3.1) (y 4))
      (test "flofix.>=" (>= 3.1 4) #f))
   (let ((x -0.2) (y 0))
      (test "flofix.<" (< x y) #t))
   (test "string->number" (string->number "7F" 16) 127)
   (test "string->number" (string->number "314t") #f)
   (test "string->number" (string->number #"5") 5)
   (test "string->number" (string->number #"-5") -5)
   (test "string->number" (string->number #"+5") 5)
   (test "string->number" (string->number #"5\n") #f)
   (test "string->number" (string->number #"-5\n") #f)
   (test "string->number" (string->number #"+5\n") #f))

==> bigloo2.6b.tar.gz: bigloo2.6b/recette/number.scm <==
;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/number.scm                   */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sat Nov 28 10:52:56 1992                          */
;*    Last change :  Wed May  7 06:40:35 2003 (serrano)                */
;*                                                                     */
;*    On test les operateurs generiques sur les nombres                */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module number
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-number)))

;*---------------------------------------------------------------------*/
;*    test-number ...                                                  */
;*---------------------------------------------------------------------*/
(define (test-number)
   (test-module "number" "number.scm")
   (test "=" (= 1 1) #t)
   (test "=" (= 1 1 1) #t)
   (test "=" (= 1 2 1) #f)
   (test "=" (= 1.0 1.0 1.0) #t)
   (test "=" (= 1.0 2.0 1.0) #f)
   (test "<" (< 1 2) #t)
   (test "<" (< 1 1) #f) 
   (test "<" (< 2 1) #f)
   (test "<" (< 1 2 3) #t)
   (test "<" (< 1 2 1 3) #f)
   (test ">" (> 1 2) #f)
   (test ">" (> 1 1) #f)
   (test ">" (> 2 1) #t)
   (test ">" (> 3 2 1) #t)
   (test ">" (> 3 1 2 1) #f)
   (test ">=" (>= 1 2) #f)
   (test ">=" (>= 1 1) #t)
   (test ">=" (>= 2 1) #t)
   (test ">=" (>= 3 2 1) #t)
   (test ">=" (>= 3 1 2 1) #f)
   (test "<=" (<= 1 2) #t)
   (test "<=" (<= 1 1) #t)
   (test "<=" (<= 2 1) #f)
   (test "<=" (<= 1 2 3) #t)
   (test "<=" (<= 1 2 1 3) #f)
   (test "+" (+ 1 2 3 4) 10)
   (test "-" (- 1 2 3 4) -8)
   (test "-" (let ((x 4.0)) (- x)) -4.0)
   (test "*" (* 1 2 3 4) 24)
   (test "/" (/ 12 3 2 1) 2)
   (test "/" (/ (/ 4)) 4.0)
   (test "/fx" (/fx 5 4) 1)
   (test "/fx" (integer? (/fx 5 4)) #t)
   (test "zero?" (zero? 3) #f)
   (test "zero?" (zero? 0) #t)
   (test "zero?" (zero? 3.0) #f)
   (test "zero?" (zero? 0.0) #t)
   (test "positive?" (positive? 5.0) #t)
   (test "positive?" (positive? -5.0) #f)
   (test "positive?" (positive? 5) #t)
   (test "positive?" (positive? -5) #f)
   (test "negative?" (negative? 5.0) #f)
   (test "negative?" (negative? -5.0) #t)
   (test "negative?" (negative? 5) #f)
   (test "negative?" (negative? -5) #t)
   (test "odd?" (odd? 4) #f)
   (test "odd?" (odd? 3) #t)
   (test "even?" (even? 4) #t)
   (test "even?" (even? 3) #f)
   (test "max" (max 3 4) 4)
   (test "max" (max 3.9 4) 4)
   (test "min" (min 3 4) 3) 
   (test "min" (min 3.9 4) 3.9)
   (test "modulo" (modulo 13 4) 1)
   (test "remainder" (remainder 13 4) 1)
   (test "modulo" (modulo -13 4) 3)
   (test "remainder" (remainder -13 4) -1)
   (test "modulo" (modulo 13 -4) -3)
   (test "remainder" (remainder 13 -4) 1)
   (test "modulo" (modulo -13 -4) -1)
   (test "remainder" (remainder -13 -4) -1)
   (test "gcd" (gcd 32 -36) 4)
   (test "gcd" (gcd) 0)
   (test "lcm" (lcm 32 -36) 288)
   (test "lcm" (lcm) 1)
   (test "flonum->fixnum" (flonum->fixnum (cosfl 0.0)) 1)
   (test "atan" (tan (atan 1)) (fixnum->flonum 1))
   (test "flofix.<" (< 3.0 3) #f)
   (test "flofix.<" (< 3.1 3) #f)
   (test "flofix.<" (< 3.1 4) #t)
   (test "flofix.>" (> 3 3.0) #f)
   (test "flofix.>" (> 3 3.1) #f)
   (test "flofix.>" (> 4 3.1) #t)
   (test "flofix.<=" (<= 3 3.0) #t)
   (test "flofix.<=" (<= 3 3.1) #t)
   (test "flofix.<=" (<= 3 2.0) #f)
   (test "flofix.>=" (>= 3.0 3) #t)
   (test "flofix.>=" (>= 3.1 3) #t)
   (test "flofix.>=" (>= 3.1 4) #f)
   (let ((x 3.0) (y 3))
      (test "flofix.<" (< x y) #f))
   (let ((x 3.1) (y 3))
      (test "flofix.<" (< x y) #f))
   (let ((x 3.1) (y 4))
      (test "flofix.<" (< x y) #t))
   (let ((x 3) (y 3.0))
      (test "flofix.>" (> x y) #f))
   (let ((x 3) (y 3.1))
      (test "flofix.>" (> x y) #f))
   (let ((x 4) (y 3.1))
      (test "flofix.>" (> x y) #t))
   (let ((x 3) (y 3.0))
      (test "flofix.<=" (<= x y) #t))
   (let ((x 3) (y 3.1))
      (test "flofix.<=" (<= x y) #t))
   (let ((x 3) (y 2.0))
      (test "flofix.<=" (<= x y) #f))
   (let ((x 3.0) (y 3))
      (test "flofix.>=" (>= x y) #t))
   (let ((x 3.1) (y 3))
      (test "flofix.>=" (>= 3.1 3) #t))
   (let ((x 3.1) (y 4))
      (test "flofix.>=" (>= 3.1 4) #f))
   (let ((x -0.2) (y 0))
      (test "flofix.<" (< x y) #t))
   (test "string->number" (string->number "0") 0)
   (test "string->number" (string->number "0" 2) 0)
   (test "string->number" (string->number "0" 8) 0)
   (test "string->number" (string->number "0" 16) 0)
   (test "string->number" (string->number "") #f)
   (test "string->number" (string->number "7F" 16) 127)
   (test "string->number" (string->number "314t") #f)
   (test "string->number" (string->number #"5") 5)
   (test "string->number" (string->number #"-5") -5)
   (test "string->number" (string->number #"+5") 5)
   (test "string->number" (string->number #"5\n") #f)
   (test "string->number" (string->number #"-5\n") #f)
   (test "string->number" (string->number #"+5\n") #f)
   (test "number->string" (number->string 0 2) "0")
   (test "number->string" (number->string 0 8) "0")
   (test "number->string" (number->string 0 10) "0")
   (test "number->string" (number->string 0 16) "0")
   (test "number->string" (number->string 7 2) "111")
   (test "number->string" (number->string -7 2) "-111")
   (test "number->string" (number->string 8 2) "1000")
   (test "number->string" (number->string -8 2) "-1000")
   (test "number->string" (number->string 9 2) "1001")
   (test "number->string" (number->string -9 2) "-1001")
   (test "number->string" (number->string 127 16) "7f")
   (test "number->string" (number->string -127 16) "-7f")
   (test "number->string" (number->string 127 8) "177")
   (test "number->string" (number->string -127 8) "-177")
   (test "elong" (find-runtime-type #e1) "elong")
   (test "elong" #e1 #e1)
   (test "elong?" (elong? #e1) #t)
   (test "elong?" (llong? #e1) #f)
   (test "elong->string" (elong->string #e1) "1")
   (test "string->elong" (string->elong "1") #e1)
   (test "elong->flonum" (elong->flonum #e123456) 123456.)
   (test "flonum->elong" (flonum->elong 123456.) #e123456)
   (test "llong" (find-runtime-type #l1) "llong")
   (test "llong" #l1 #l1)
   (test "llong?" (llong? #l1) #t)
   (test "llong?" (llong? #e1) #f)
   (test "llong->string" (llong->string #l1) "1")
   (test "string->llong" (string->llong "1") #l1)
   (test "llong->flonum" (llong->flonum #l123456) 123456.)
   (test "flonum->llong" (flonum->llong 123456.) #l123456)
   (test "integer?.1" (integer? 1) #t)
   (test "integer?.2" (integer? 1.) #t)
   (test "integer?.3" (integer? 1.1) #f)
   (test "fixnum?.1" (fixnum? 1) #t)
   (test "fixnum?.2" (fixnum? 1.) #f)
   (test "fixnum?.3" (fixnum? 1.1) #f))
